![](https://chacha.ddns.net/jenkins/buildStatus/icon?subject=status&status=active&color=seagreen)
![](https://chacha.ddns.net/jenkins/buildStatus/icon?subject=doc&status=MkDocs&color=blue)
![](https://chacha.ddns.net/jenkins/buildStatus/icon?subject=jenkins-unittest&job=chacha_cicd_helper-{{branch}})
![](https://chacha.ddns.net/jenkins/buildStatus/icon?job=chacha_cicd_helper-{{branch}}&build=0&config=coverage)
![](https://chacha.ddns.net/jenkins/buildStatus/icon?job=chacha_cicd_helper-{{branch}}&build=0&config=maintainability)
![](https://chacha.ddns.net/jenkins/buildStatus/icon?job=chacha_cicd_helper-{{branch}}&build=0&config=quality)
![](https://chacha.ddns.net/jenkins/buildStatus/icon?subject=licence&status=CC%20BY-NC-SA%204.0&color=teal)

![](docs-static/Library.jpg)

A set of tool to help continuous integration.

Checkout [Latest Documentation](https://chacha.ddns.net/mkdocs-web/chacha/chacha_cicd_helper/master/latest/).
